'use strict';

var constants = require('../constants');
var utils = require('../utils');

var query_default = {
  async run(node, input, processor) {
    const { collection, multiple, params = {}, failOnEmpty = false } = node.config;
    const repo = node.constructor.database.getRepository(collection);
    const options = processor.getParsedValue(params, node);
    const appends = options.appends ? Array.from(
      options.appends.reduce((set, field) => {
        set.add(field.split(".")[0]);
        set.add(field);
        return set;
      }, /* @__PURE__ */ new Set())
    ) : options.appends;
    const result = await (multiple ? repo.find : repo.findOne).call(repo, {
      ...options,
      appends,
      transaction: processor.transaction
    });
    if (failOnEmpty && (multiple ? !result.length : !result)) {
      return {
        result,
        status: constants.JOB_STATUS.FAILED
      };
    }
    return {
      result: utils.toJSON(result),
      status: constants.JOB_STATUS.RESOLVED
    };
  }
};

module.exports = query_default;
